<?php
	/*=======================================================================
	 * copyright (c) AL-Design Works 
	 * http://cms.al-design.jp/
	 * このソースファイルは CMS Designer の一部です。
	 * 詳しいライセンス規約についてはウェブサイトを参照してください。
	 *=======================================================================
	 */

	require_once( dirname(__FILE__) . "/app.php.inc" );
	require_once( dirname(__FILE__) . "/manager.util.php.inc" );
	
	require_once( dirname(__FILE__) . "/manager.base.php.inc" );

	/* --------------------------------------------------------------------
	 * 整数入力項目クラス。
	 * 
	 */ 
	class MenuEntryItem extends BaseEntryItem
	{
		var $menuitems = NULL;
		//var $defaultId = NULL;  // BaseEntryItemにinitDataメンバが追加された事により不要となった。
		
		/* ----------------------------------------------------------------
		 * コンストラクタ。
		 * $xmlSchemaData : 対応するスキーマDataのXML要素。
		 */
		function MenuEntryItem( $xmlSchemaData, $entryName, $entryId  )
		{
			// ベースコンストラクタの呼び出し。
			parent::BaseEntryItem( $xmlSchemaData, $entryName, $entryId  );
			
			// メニュー要素を配列として取得。
			$this->menuitems = array();
			foreach( $xmlSchemaData->child_nodes() as $node )
			{
				if ( $node->node_type() == XML_ELEMENT_NODE and $node->tagname() == 'menuitem' )
				{
					if ( $this->initData == '' )
					{
						$this->initData = file2code( $node->get_attribute('id') );
					}
					$this->menuitems[ file2code( $node->get_attribute('id') ) ] = file2code( $node->get_content() );
				}
			}
			
			// データソースが指定されていた場合、そちらから読み込む
			$siteConfig = new CMSSiteConfig();
			$entryConfig = $siteConfig->getEntryConfig( $entryName );
			$dataSource = $entryConfig->getDatasource( $this->dataName );
			
			if ( !empty( $dataSource ) ){
				$this->menuitems = $dataSource->menuItems;
			}
			
		}
		
		/* ----------------------------------------------------------------
		 * 当項目のXMLノードを新規作成する。
		 * $xmlDocParentEntry : エントリのDOMオブジェクト。
		 * $setInitData : 初期値。trueが指定されていた場合、スキーマで指定された値が設定される。デフォルト値はtrue。
		 * return : 新規XMLノード。
		 */
		function createNew( $xmlDocParentEntry, $setInitData = true )
		{
			$newNode = parent::createNew( $xmlDocParentEntry, $setInitData );
			//$newNode->set_content( fileconv( $this->defaultId ) );
			
			return $newNode;
		}
		
		
		/* ----------------------------------------------------------------
		 * 入力内容でエントリ項目を更新する。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function update( $xpathEntry, $currentEntry )
		{
			// エントリXMLを取得。
			$xmlEntryDataList = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$xmlEntryData = $xmlEntryDataList->nodeset[0];

			// "name"属性に対応するPOSTが存在すれば、エントリに反映する。
			if ( isset( $_POST[ $this->dataName ] ) )
			{
				$datavalue = $_POST[ $this->dataName ];
				
				// 範囲チェック（選択肢中に存在するIDか）
				if ( ! in_array( $datavalue, array_keys($this->menuitems) ) )
				{
					$this->errorMessage = sprintf( "%s に存在しない選択肢が指定されました。", $this->dataCaption );
					return false;
				}
				
				// まず、テキストノードを削除する（削除しないと、set_contentではテキストノードが増えるだけ）。
				$xmlEntryData = $xmlEntryDataList->nodeset[0];
				EntryUtil::deleteTextNode( $xmlEntryData );
				
				// テキストノードに新しい値をsetする。
				$xmlEntryData->set_content( fileconv( $datavalue ) );
				//print( $dataname . " = " . htmlconv( $datavalue ) . "<br>\n" );
			}
			
			return true;
		
		}
		
		/* ----------------------------------------------------------------
		 * フォーム項目を描画するHTMLを返す。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function renderFormItem( $xpathEntry, $currentEntry )
		{
			$xmlEntryDataArray = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$value = $xmlEntryDataArray->nodeset[0]->get_content();
			
			$strFormHTML = '<select name="' . $this->dataName . '">' . "\n";
			
			foreach ( $this->menuitems as $itemKey => $itemCaption )
			{
				if ( $itemKey == $value )
				{
					$selected = 'selected';
				}
				else
				{
					$selected = '';
				}
				
				$strFormHTML .= '	 <option value="' . $itemKey . '" ' . $selected . ' >' . htmlconv($itemCaption) . '</option>' . "\n";
			}
			
			$strFormHTML .= '</select>' . "\n";
			
			return $strFormHTML;
		}
		
		/* ----------------------------------------------------------------
		 * フォーム項目を描画するHTMLを返す。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function renderFormItemXML( $xpathEntry, $currentEntry, &$xmlOutputEntryData )
		{
			$xmlEntryDataArray = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$value = $xmlEntryDataArray->nodeset[0]->get_content();
			
			// リクエストに値があれば、その値を再表示する（エラー時に前回入力値が保証されるようにする）
			if ( isset( $_POST[ $this->dataName ] ) )
			{
				$value = $_POST[ $this->dataName ];
			}
			
			$xmlDocOutput = $xmlOutputEntryData->owner_document();
			
			foreach ( $this->menuitems as $itemKey => $itemCaption )
			{
				$xmlOutputOption = $xmlDocOutput->create_element('option');
				
				if ( $itemKey == $value )
				{
					$xmlOutputOption->set_attribute('selected', 'selected');
				}
				
				$xmlOutputOption->set_attribute('value', fileconv( $itemKey ) );
				$xmlOutputOption->set_content( fileconv( $itemCaption ) );
				
				$xmlOutputEntryData->append_child( $xmlOutputOption );
			}
			
		}		
		
	}

?>